==> mir_0.1.8+14.04.20140411.orig.tar.gz: mir-0.1.8+14.04.20140411/src/server/report/lttng/input_report.h <==
/*
 * Copyright © 2013 Canonical Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 3,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authored by: Alan Griffiths <alan@octopull.co.uk>
 */

#ifndef MIR_REPORT_LTTNG_INPUT_REPORT_H_
#define MIR_REPORT_LTTNG_INPUT_REPORT_H_

#include "server_tracepoint_provider.h"

#include "mir/input/input_report.h"

namespace mir
{
namespace report
{
namespace lttng
{

class InputReport : public input::InputReport
{
public:
    InputReport() = default;
    virtual ~InputReport() noexcept(true) = default;

    void received_event_from_kernel(int64_t when, int type, int code, int value) override;

    void published_key_event(int dest_fd, uint32_t seq_id, int64_t event_time) override;
    void published_motion_event(int dest_fd, uint32_t seq_id, int64_t event_time) override;

    void received_event_finished_signal(int src_fd, uint32_t seq_id) override;

private:
    ServerTracepointProvider tp_provider;
};

}
}
}


#endif /* MIR_REPORT_LTTNG_INPUT_REPORT_H_ */

==> mir_0.17.0+15.10.20151008.2.orig.tar.gz: mir-0.17.0+15.10.20151008.2/src/server/report/lttng/input_report.h <==
/*
 * Copyright © 2013 Canonical Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 3,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authored by: Alan Griffiths <alan@octopull.co.uk>
 */

#ifndef MIR_REPORT_LTTNG_INPUT_REPORT_H_
#define MIR_REPORT_LTTNG_INPUT_REPORT_H_

#include "server_tracepoint_provider.h"

#include "mir/input/input_report.h"

namespace mir
{
namespace report
{
namespace lttng
{

class InputReport : public input::InputReport
{
public:
    InputReport() = default;
    virtual ~InputReport() noexcept(true) = default;

    void received_event_from_kernel(int64_t when, int type, int code, int value) override;

    void published_key_event(int dest_fd, uint32_t seq_id, int64_t event_time) override;
    void published_motion_event(int dest_fd, uint32_t seq_id, int64_t event_time) override;

    void received_event_finished_signal(int src_fd, uint32_t seq_id) override;

    void opened_input_device(char const* device_name, char const* input_platform) override;
    void failed_to_open_input_device(char const* device_name, char const* input_platform) override;
private:
    ServerTracepointProvider tp_provider;
};

}
}
}


#endif /* MIR_REPORT_LTTNG_INPUT_REPORT_H_ */
